#######
Bot API
#######

**litegram** now is fully support of `Telegram Bot API <https://core.telegram.org/bots/api>`_

All methods and types is fully autogenerated from Telegram Bot API docs by parser with code-generator.

.. toctree::
    bot
    session/index
    types/index
    methods/index
    enums/index
    download_file
    upload_file
    defaults
